#!/usr/bin/python
'''
This node is used to process point clouds.
Currently, this node only updates the timestamps, to make RViz like the messages
'''
import sys
import subprocess

import roslib
roslib.load_manifest('process_visualizer')
import rospy
import tf
from tf.transformations import quaternion_from_euler
import gui
from xmlparser import XmlParser

#from std_msgs.msg import Float32MultiArray
from sensor_msgs.msg import PointCloud2
#from visualization_msgs.msg import MarkerArray, Marker
#from geometry_msgs.msg import Quaternion, Point, Vector3




class DepthProcessor():
    '''
    This is the main class, used to process Pointclouds
    '''
    def __init__(self, my_name, config_path):
        #self.name = rospy.names.get_namespace().replace('/', '')
        #main_pkg_path = roslib.packages.get_pkg_dir('process_visualizer')
        #parser = XmlParser(main_pkg_path)
        #self.device = parser.get_device(self.name)
        self.device = XmlParser(config_path).get_device(my_name)
        
        ### Fetch the pointcloud topic
        topic = ''
        for top in self.device.topics:
            if top[1] == 'pointcloud':
                topic = top[0]
        if topic == '':
            sys.exit("Could not find a pointcloud topic in the xml configuration.")
        
        ### Publish/subscribe stuff
        rospy.Subscriber(topic, PointCloud2, self.cloud_cb)
        self.cloud_pub = rospy.Publisher('/' + self.device.name + '/points', PointCloud2)
        
    
    def cloud_cb(self, msg):
        '''
        Callback function for the point cloud.
        This function simply updates the timestamp,
        to make RViz like the messages...
        '''
        msg.header.stamp = rospy.Time.now()
        self.cloud_pub.publish(msg)
    


def main():
    '''
    Simply the main function...
    '''
    rospy.init_node('depth_proc')
    
    DepthProcessor(sys.argv[1], sys.argv[2])
    
    rospy.spin()


if __name__ == '__main__':
    main()
