import sys


# Use this class to manipulate rviz config files
# @todo: make better..? include other display types etc...
class RVizConfig(object):
    def __init__(self, pkg_path):
        path = pkg_path + '/rviz_config'
        default_filename = 'default.vcg'
        self.out_filename = path + '/auto_generated.vcg'
        in_file = open(path + '/' + default_filename, 'r')
        self.out_file = open(self.out_filename, 'w')
        self.out_file.write(in_file.read())
        self.display_count = 0
        in_file.close()
        
        self.bottom_text = ''
        self.add_bottom('Grid', 'Grid')
        
    def add(self, name, displays):
        for type in displays:
            fullname = name + '_' + type.lower()
            self.out_file.write(fullname + '.Enabled=1\n')
            # stuff that's different depending on the type:
            if type == 'RobotModel':
                self.out_file.write(fullname + '.Robot\ Description=' +
                                    name + '/robot_description\n')
                self.out_file.write(fullname + '.TF\ Prefix=' + name + '\n')
            elif type == 'MarkerArray':
                self.out_file.write(fullname + '.Marker\ Array\ Topic=' +
                                    name + '/marker_array\n')
            elif type == 'Marker':
                self.out_file.write(fullname + '.Marker\ Topic=' + name + '/marker\n')
            elif type == 'PointCloud2':
                self.out_file.write(fullname + '.Color\ Transformer=RGB8\n')
                self.out_file.write(fullname + '.Style=0\n')
                self.out_file.write(fullname + '.Topic=' + name + '/points\n')
            else:
                sys.exit("ERROR: The display type " + type + " is not supported. " +
                         "Please add this to rvizconfig.py or choose a " +
                         "different display type. (for " + name + ')')
        
            self.add_bottom(fullname, type)


    def add_bottom(self, name, type):
        '''
        This information has to be at the bottom of the config file
        (for some reason I do not know...)
        '''
        self.bottom_text += '[Display' + str(self.display_count) + ']\n'
        self.bottom_text += 'Name=' + name + '\n'
        self.bottom_text += 'Package=rviz\n'
        self.bottom_text += 'ClassName=rviz::' + type + 'Display\n'
        self.display_count += 1


    def close(self):
        self.out_file.write(self.bottom_text)
        self.out_file.close()
        return self.out_filename
    







